Point

Struct Point 

pub struct Point<T> { /* private fields */ }
A structure representing a single value repeated multiple times.

This is useful for creating queries or representing repeated elements without allocating a vector.

Implementations

Source

impl<T: PartialEq> Point<T>

pub const fn new(index: T, size: usize) -> Self

pub const fn is_empty(&self) -> bool

pub const fn len(&self) -> usize

pub fn is_full(link: &[T]) -> bool

pub fn is_partial(link: &[T]) -> bool

pub const fn get(&self, index: usize) -> Option<&T>