Crate platform_data
platform_
data
1.0.0
All Items
Crate Items
Macros
Structs
Enums
Traits
Type Aliases
Crate
platform_
data
Macros

query
Structs

Addr
ToRaw
Hybrid
Links
Constants
Point
A structure representing a single value repeated multiple times.
Point
Iter
Iterator for Point that yields copies of the stored value.
Query
RawTo
Addr
Enums

Error
Flow
Represents the control flow of an operation, similar to
ControlFlow
.
Traits

Link
Type
Trait bound for numeric types that can be used as link identifiers.
Links
ToQuery
Type Aliases

Read
Handler
Write
Handler