Flow

Enum Flow 

#[repr(usize)]
pub enum Flow { Continue = 0, Break = 1, }
Represents the control flow of an operation, similar to ControlFlow.

This is a simplified enum that can be used with iterators and callbacks to indicate whether to continue or break early.

Variants



Continue = 0



Break = 1

Implementations

Source

impl Flow

pub const fn is_continue(&self) -> bool

Returns true if this is Flow::Continue.

pub const fn is_break(&self) -> bool

Returns true if this is Flow::Break.

pub const fn into_control_flow(self) -> ControlFlow<()>

Converts this Flow into a ControlFlow that can be used with try_for_each.

use platform_data::Flow;
use std::ops::ControlFlow;

let mut count = 0;
let result = (0..10).try_for_each(|i| {
    count += 1;
    if i == 5 { Flow::Break.into_control_flow() } else { Flow::Continue.into_control_flow() }
});
assert_eq!(count, 6);